@@ -60,39 +60,49 @@ slapos_controler = None
 def run(args):
   config = args[0]
   slapgrid = None
-  branch = config.get('branch', None)
   supervisord_pid_file = os.path.join(config['instance_root'], 'var', 'run',
         'supervisord.pid')
   subprocess.check_call([config['git_binary'],
                 "config", "--global", "http.sslVerify", "false"])
   previous_revision = None
-  run_software = True
-  # find what will be the path of the repository
-  repository_name = config['vcs_repository'].split('/')[-1].split('.')[0]
-  repository_path = os.path.join(config['working_directory'],repository_name)
-  config['repository_path'] = repository_path
-  sys.path.append(repository_path)
 
+  run_software = True
   # Write our own software.cfg to use the local repository
   custom_profile_path = os.path.join(config['working_directory'], 'software.cfg')
   config['custom_profile_path'] = custom_profile_path
-  
-  # create a profile in order to use the repository we already have
-  custom_profile = open(custom_profile_path, 'w')
-  profile_content = """
+  vcs_repository_list = config['vcs_repository_list']
+  profile_content = None
+  assert len(vcs_repository_list), "we must have at least one repository"
+  for vcs_repository in vcs_repository_list:
+    url = vcs_repository['url']
+    buildout_section_id = vcs_repository.get('buildout_section_id', None)
+    repository_id = buildout_section_id or \
+                                  url.split('/')[-1].split('.')[0]
+    repository_path = os.path.join(config['working_directory'],repository_id)
+    vcs_repository['repository_id'] = repository_id
+    vcs_repository['repository_path'] = repository_path
+    if profile_content is None:
+      profile_content = """
 [buildout]
 extends = %(software_config_path)s
-
-[%(repository_name)s]
+""" %  {'software_config_path': os.path.join(repository_path,
+                                          config['profile_path'])}
+    if not(buildout_section_id is None):
+      profile_content += """
+[%(buildout_section_id)s]
 repository = %(repository_path)s
-""" %     {'software_config_path': os.path.join(repository_path,
-                                          config['profile_path']),
-    'repository_name': repository_name,
-    'repository_path' : repository_path}
-  if branch is not None:
-    profile_content += "\nbranch = %s" % branch
+branch = %(branch)s
+""" %  {'buildout_section_id': buildout_section_id,
+        'repository_path' : repository_path,
+        'branch' : vcs_repository.get('branch','master')}
+
+  custom_profile = open(custom_profile_path, 'w')
   custom_profile.write(profile_content)
   custom_profile.close()
+  config['repository_path'] = repository_path
+  sys.path.append(repository_path)
+  test_suite_title = config['test_suite_title'] or config['test_suite']
+
   retry_software = False
   try:
     while True:
@@ -104,19 +114,24 @@ repository = %(repository_path)s
           except:
             pass
         process_group_pid_set.clear()
+        full_revision_list = []
         # Make sure we have local repository
-        if not os.path.exists(repository_path):
-          parameter_list = [config['git_binary'], 'clone',
-                            config['vcs_repository']]
-          if branch is not None:
-            parameter_list.extend(['-b',branch])
-          parameter_list.append(repository_path)
-          subprocess.check_call(parameter_list)
-          # XXX this looks like to not wait the end of the command
-        # Make sure we have local repository
-        updater = Updater(repository_path, git_binary=config['git_binary'])
-        updater.checkout()
-        revision = updater.getRevision()
+        for vcs_repository in vcs_repository_list:
+          repository_path = vcs_repository['repository_path']
+          repository_id = vcs_repository['repository_id']
+          if not os.path.exists(repository_path):
+            parameter_list = [config['git_binary'], 'clone',
+                              vcs_repository['url']]
+            if vcs_repository.get('branch') is not None:
+              parameter_list.extend(['-b',vcs_repository.get('branch')])
+            parameter_list.append(repository_path)
+            subprocess.check_call(parameter_list)
+          # Make sure we have local repository
+          updater = Updater(repository_path, git_binary=config['git_binary'])
+          updater.checkout()
+          revision = "-".join(updater.getRevision())
+          full_revision_list.append('%s=%s' % (repository_id, revision))
+        revision = ','.join(full_revision_list)
         if previous_revision == revision:
           time.sleep(120)
           if not(retry_software):
@@ -137,17 +152,21 @@ repository = %(repository_path)s
           master = portal.portal_task_distribution
           assert master.getProtocolRevision() == 1
           test_result = safeRpcCall(master.createTestResult,
-            config['test_suite_name'], revision, [],
-            False, config['test_suite_title'])
+            config['test_suite'], revision, [],
+            False, test_suite_title,
+            config['test_node_title'], config['project_title'])
         print "testnode, test_result : %r" % (test_result,)
         if test_result:
           test_result_path, test_revision = test_result
           if revision != test_revision:
-            # other testnodes on other boxes are already ready to test another
-            # revision
-            updater = Updater(repository_path, git_binary=config['git_binary'],
-                              revision=test_revision)
-            updater.checkout()
+            for i, repository_revision in enumerate(test_revision.split(',')):
+              vcs_repository = vcs_repository_list[i]
+              repository_path = vcs_repository['repository_path']
+              # other testnodes on other boxes are already ready to test another
+              # revision
+              updater = Updater(repository_path, git_binary=config['git_binary'],
+                                revision=repository_revision.split('-')[1])
+              updater.checkout()
 
           # Now prepare the installation of SlapOS
           slapos_controler = SlapOSControler(config,
@@ -159,7 +178,7 @@ repository = %(repository_path)s
             )
           if status_dict['status_code'] != 0:
             safeRpcCall(master.reportTaskFailure,
-              test_result_path, status_dict, config['test_suite_title'])
+              test_result_path, status_dict, config['test_node_title'])
             retry_software = True
             continue
 
@@ -169,24 +188,21 @@ repository = %(repository_path)s
 
           # update repositories downloaded by buildout. Later we should get
           # from master a list of repositories
-          repository_path_list = glob(os.path.join(config['software_root'],
-                                  '*', 'parts', 'git_repository', '*'))
-          assert len(repository_path_list) >= 0
-          for repository_path in repository_path_list:
-            updater = Updater(repository_path, git_binary=config['git_binary'])
-            updater.checkout()
-            if os.path.split(repository_path)[-1] == repository_name:
-              # redo checkout with good revision, the previous one is used
-              # to pull last code
-              updater = Updater(repository_path, git_binary=config['git_binary'],
-                                revision=revision)
-              updater.checkout()
-            # calling dist/externals is only there for backward compatibility,
-            # the code will be removed soon
-            if os.path.exists(os.path.join(repository_path, 'dist/externals.py')):
-              process = subprocess.Popen(['dist/externals.py'],
-                        cwd=repository_path)
-              process.wait()
+
+          # The section below seems useless since we override buildout
+          # configuration to use local checkouts
+          #repository_path_list = glob(os.path.join(config['software_root'],
+                                  #'*', 'parts', 'git_repository', '*'))
+          #assert len(repository_path_list) >= 0
+          #for repository_path in repository_path_list:
+            #updater = Updater(repository_path, git_binary=config['git_binary'])
+            #updater.checkout()
+            #if os.path.split(repository_path)[-1] == repository_name:
+              ## redo checkout with good revision, the previous one is used
+              ## to pull last code
+              #updater = Updater(repository_path, git_binary=config['git_binary'],
+                                #revision=revision)
+              #updater.checkout()
 
           partition_path = os.path.join(config['instance_root'],
                                         config['partition_reference'])
@@ -206,8 +222,9 @@ repository = %(repository_path)s
           if line[:2] == '#!':
             invocation_list = line[2:].split()
           invocation_list.extend([run_test_suite_path,
-                                  '--test_suite', config['test_suite_name'],
+                                  '--test_suite', config['test_suite'],
                                   '--revision', revision,
+                                  '--test_suite_title', test_suite_title,
                                   '--node_quantity', config['node_quantity'],
                                   '--master_url', config['test_suite_master_url']])
           run_test_suite = subprocess.Popen(invocation_list)
